# NLFE Package

This is a NON-LINEAR FEATURE EXTRACTION package. You can use it extract non-linear features of time series,including 
**1. approximate entropy** ,  **2. sample entropy** , **3. fuzzy entropy,poincare plot**,  **4. recurrence plot**  and so forth.